#This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Refer to the README and COPYING files for full details of the license
#
from __future__ import absolute_import

import subprocess

from vdsm.common import cache

def _parse_sysinfo(sysinfo_str):
    res_lines = sysinfo_str.decode().replace('\t','').split('\n')
    keys = ['Manufacturer', 'Product Name', 'Version', 'Serial Number',
              'UUID', 'Family']
    parse_start = False
    sys_struct = {}
    for line in res_lines:
        # start parse at 'System Information'
        if line == 'System Information':
            parse_start = True
            continue
        if not parse_start:
            continue
        # stop parse at another 'Handle'
        if line[:6] == 'Handle':
            break
        if ':' in line:
            (k, v) = line.split(':', 1)
            for key in keys:
                if k == key and v not in [None, 'Not Specified']:
                    sys_struct[('system' + k).replace(' ', '')] = v
    return sys_struct

@cache.memoized
def getHardwareInfoStructure():
    p_dmidecode = subprocess.Popen(['/bin/bash', '-c', 'dmidecode -t system'], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
    (res_dmidecode, _) = p_dmidecode.communicate()
    if p_dmidecode.returncode != 0:
        # error occured
        return {}
    return _parse_sysinfo(res_dmidecode)